@@ -29,8 +29,7 @@ from telegram.error import InvalidToken
 from telegram.utils import request
 from telegram.utils.validate import validate_string
 
-H = NullHandler()
-logging.getLogger(__name__).addHandler(H)
+logging.getLogger(__name__).addHandler(NullHandler())
 
 
 class Bot(TelegramObject):
@@ -161,6 +160,10 @@ class Bot(TelegramObject):
             reply_to_message_id = kwargs.get('reply_to_message_id')
             data['reply_to_message_id'] = reply_to_message_id
 
+        if kwargs.get('disable_notification'):
+            disable_notification = kwargs.get('disable_notification')
+            data['disable_notification'] = disable_notification
+
         if kwargs.get('reply_markup'):
             reply_markup = kwargs.get('reply_markup')
             if isinstance(reply_markup, ReplyMarkup):
@@ -206,13 +209,17 @@ class Bot(TelegramObject):
           chat_id:
             Unique identifier for the message recipient - telegram.Chat id.
           parse_mode:
-            Send Markdown, if you want Telegram apps to show bold, italic and
-            inline URLs in your bot's message. For the moment, only Telegram
-            for Android supports this. [Optional]
+            Send 'Markdown', if you want Telegram apps to show bold, italic and
+            inline URLs in your bot's message. [Optional]
           text:
-            Text of the message to be sent.
+            Text of the message to be sent. The current maximum length is 4096
+            UTF8 characters.
           disable_web_page_preview:
             Disables link previews for links in this message. [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -252,6 +259,10 @@ class Bot(TelegramObject):
             - Chat id.
           message_id:
             Unique message identifier.
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
 
         Returns:
           A telegram.Message instance representing the message forwarded.
@@ -288,6 +299,10 @@ class Bot(TelegramObject):
           caption:
             Photo caption (may also be used when resending photos by file_id).
             [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -342,6 +357,10 @@ class Bot(TelegramObject):
             Performer of sent audio. [Optional]
           title:
             Title of sent audio. [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -386,6 +405,10 @@ class Bot(TelegramObject):
           filename:
             File name that shows in telegram message (it is usefull when you
             send file generated by temp module, for example). [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -422,6 +445,10 @@ class Bot(TelegramObject):
             Sticker to send. You can either pass a file_id as String to resend
             a sticker that is already on the Telegram servers, or upload a new
             sticker using multipart/form-data.
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -466,6 +493,10 @@ class Bot(TelegramObject):
           timeout:
             float. If this value is specified, use it as the definitive timeout
             (in seconds) for urlopen() operations. [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -512,6 +543,10 @@ class Bot(TelegramObject):
             a new audio file using multipart/form-data.
           duration:
             Duration of sent audio in seconds. [Optional]
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -549,6 +584,10 @@ class Bot(TelegramObject):
             Latitude of location.
           longitude:
             Longitude of location.
+          disable_notification:
+            Sends the message silently. iOS users will not receive
+            a notification, Android users will receive a notification
+            with no sound. Other apps coming soon. [Optional]
           reply_to_message_id:
             If the message is a reply, ID of the original message. [Optional]
           reply_markup:
@@ -757,7 +796,7 @@ class Bot(TelegramObject):
         result = request.post(url, data, network_delay=network_delay)
 
         if result:
-            self.logger.info(
+            self.logger.debug(
                 'Getting updates: %s', [u['update_id'] for u in result])
         else:
             self.logger.debug('No new updates found.')
